@@ -22,8 +22,10 @@ bib2df<-function(D, dbsource = "isi"){
   
   if (dbsource == "isi") D <- gsub(" = \\{","={",D)
   
+  D <- gsub("\\\t","",gsub(" = \\{","=\\{",D)) # to work also with new scopus bib format
+  
   D[Papers] <- paste("Paper={",D[Papers],sep="")
-  #ii <- regexpr("\\{",D[Papers])
+
   ind <- regexpr("=\\{",D) # sep among tags and contents
   ind[Papers] <- 6
   
@@ -194,6 +196,11 @@ postprocessing <-function(DATA,dbsource){
   DI <- DATA$DI
   URL <- DATA$url
   DATA <- data.frame(lapply(DATA,toupper),stringsAsFactors = FALSE)
+  if ("JI" %in% names(DATA)){
+    DATA$J9 <- gsub("\\.","",DATA$JI)
+  }else{
+    DATA$J9 <- DATA$JI <- sapply(DATA$SO, AbbrevTitle, USE.NAMES = FALSE)
+  }
   DATA$DI <- DI
   DATA$url <- URL
   return(DATA)
