@@ -51,7 +51,7 @@ g=ggplot2::ggplot(df, aes(x = log(.data$Rank), y = .data$Freq, text=paste("Sourc
   geom_line(aes(group="NA")) +
   geom_area(aes(group="NA"),fill = "gray90", alpha = 0.5) +
   annotate("rect", xmin=0, xmax=log(df$Rank[a]), ymin=0, ymax=max(df$Freq), alpha=0.2)+
-  labs(x = 'Source log(Rank)', y = 'Articles', title = "Bradford's Law") +
+  labs(x = 'Source log(Rank)', y = 'Articles', title = "Core Sources by Bradford's Law") +
   annotate("text",x=log(df$Rank[a])/2, y=max(df$Freq)/2, label = "Core\nSources",fontface =2,alpha=0.5,size=10)+
   scale_x_continuous(breaks=log(df$Rank)[1:a],labels=as.character(substr(df$SO,1,25))[1:a]) +
   theme(text = element_text(color = "#444444")
